@@ -1,31 +1,34 @@
 # -*- coding: utf-8 -*-
-
 """The bru2nii module provides basic functions for dicom conversion
-
-    Change directory to provide relative paths for doctests
-    >>> import os
-    >>> filepath = os.path.dirname( os.path.realpath( __file__ ) )
-    >>> datadir = os.path.realpath(os.path.join(filepath, '../testing/data'))
-    >>> os.chdir(datadir)
 """
-from __future__ import print_function, division, unicode_literals, absolute_import
+from __future__ import (print_function, division, unicode_literals,
+                        absolute_import)
 
 import os
-from .base import (CommandLine, CommandLineInputSpec,
-                   traits, TraitedSpec, isdefined, File, Directory)
+from .base import (CommandLine, CommandLineInputSpec, traits, TraitedSpec,
+                   isdefined, File, Directory)
 
 
 class Bru2InputSpec(CommandLineInputSpec):
     input_dir = Directory(
-        desc="Input Directory", exists=True, mandatory=True, position=-1, argstr="%s")
+        desc="Input Directory",
+        exists=True,
+        mandatory=True,
+        position=-1,
+        argstr="%s")
     actual_size = traits.Bool(
-        argstr='-a', desc="Keep actual size - otherwise x10 scale so animals match human.")
+        argstr='-a',
+        desc="Keep actual size - otherwise x10 scale so animals match human.")
     force_conversion = traits.Bool(
-        argstr='-f', desc="Force conversion of localizers images (multiple slice orientations).")
+        argstr='-f',
+        desc="Force conversion of localizers images (multiple slice "
+        "orientations).")
     append_protocol_name = traits.Bool(
         argstr='-p', desc="Append protocol name to output filename.")
     output_filename = traits.Str(
-        argstr="-o %s", desc="Output filename ('.nii' will be appended)", genfile=True)
+        argstr="-o %s",
+        desc="Output filename ('.nii' will be appended)",
+        genfile=True)
 
 
 class Bru2OutputSpec(TraitedSpec):
@@ -33,7 +36,6 @@ class Bru2OutputSpec(TraitedSpec):
 
 
 class Bru2(CommandLine):
-
     """Uses bru2nii's Bru2 to convert Bruker files
 
     Examples
@@ -42,7 +44,7 @@ class Bru2(CommandLine):
     >>> from nipype.interfaces.bru2nii import Bru2
     >>> converter = Bru2()
     >>> converter.inputs.input_dir = "brukerdir"
-    >>> converter.cmdline  # doctest: +ELLIPSIS +ALLOW_UNICODE
+    >>> converter.cmdline  # doctest: +ELLIPSIS
     'Bru2 -o .../nipype/testing/data/brukerdir brukerdir'
     """
     input_spec = Bru2InputSpec
@@ -55,11 +57,12 @@ class Bru2(CommandLine):
             output_filename1 = os.path.abspath(self.inputs.output_filename)
         else:
             output_filename1 = self._gen_filename('output_filename')
-        outputs["nii_file"] = output_filename1+".nii"
+        outputs["nii_file"] = output_filename1 + ".nii"
         return outputs
 
     def _gen_filename(self, name):
         if name == 'output_filename':
             outfile = os.path.join(
-                os.getcwd(), os.path.basename(os.path.normpath(self.inputs.input_dir)))
+                os.getcwd(),
+                os.path.basename(os.path.normpath(self.inputs.input_dir)))
             return outfile
