@@ -3,20 +3,19 @@
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Tests for join expansion
 """
-from __future__ import print_function, division, unicode_literals, absolute_import
+from __future__ import (print_function, division, unicode_literals,
+                        absolute_import)
 from builtins import open
 
-import os
-
 from ... import engine as pe
 from ....interfaces import base as nib
-from ....interfaces.utility import IdentityInterface
+from ....interfaces.utility import IdentityInterface, Function, Merge
 from ....interfaces.base import traits, File
 
 
 class PickFirstSpec(nib.TraitedSpec):
-    in_files = traits.List(File(exists=True), argstr="%s", position=2,
-                           mandatory=True)
+    in_files = traits.List(
+        File(exists=True), argstr="%s", position=2, mandatory=True)
 
 
 class PickFirstOutSpec(nib.TraitedSpec):
@@ -59,6 +58,7 @@ class IncrementInterface(nib.BaseInterface):
         outputs['output1'] = self.inputs.input1 + self.inputs.inc
         return outputs
 
+
 _sums = []
 
 _sum_operands = []
@@ -163,8 +163,11 @@ def test_join_expansion(tmpdir):
     pre_join2 = pe.Node(IncrementInterface(), name='pre_join2')
     wf.connect(pre_join1, 'output1', pre_join2, 'input1')
     # the join node
-    join = pe.JoinNode(SumInterface(), joinsource='inputspec',
-                       joinfield='input1', name='join')
+    join = pe.JoinNode(
+        SumInterface(),
+        joinsource='inputspec',
+        joinfield='input1',
+        name='join')
     wf.connect(pre_join2, 'output1', join, 'input1')
     # an uniterated post-join node
     post_join1 = pe.Node(IncrementInterface(), name='post_join1')
@@ -182,10 +185,12 @@ def test_join_expansion(tmpdir):
     # the expanded graph contains 2 * 2 = 4 iteration pre-join nodes, 1 join
     # node, 1 non-iterated post-join node and 2 * 1 iteration post-join nodes.
     # Nipype factors away the IdentityInterface.
-    assert len(result.nodes()) == 8, "The number of expanded nodes is incorrect."
+    assert len(
+        result.nodes()) == 8, "The number of expanded nodes is incorrect."
     # the join Sum result is (1 + 1 + 1) + (2 + 1 + 1)
     assert len(_sums) == 1, "The number of join outputs is incorrect"
-    assert _sums[0] == 7, "The join Sum output value is incorrect: %s." % _sums[0]
+    assert _sums[
+        0] == 7, "The join Sum output value is incorrect: %s." % _sums[0]
     # the join input preserves the iterables input order
     assert _sum_operands[0] == [3, 4], \
         "The join Sum input is incorrect: %s." % _sum_operands[0]
@@ -198,18 +203,16 @@ def test_node_joinsource(tmpdir):
     """Test setting the joinsource to a Node."""
     tmpdir.chdir()
 
-    # Make the workflow.
-    wf = pe.Workflow(name='test')
     # the iterated input node
     inputspec = pe.Node(IdentityInterface(fields=['n']), name='inputspec')
     inputspec.iterables = [('n', [1, 2])]
     # the join node
-    join = pe.JoinNode(SetInterface(), joinsource=inputspec,
-                       joinfield='input1', name='join')
+    join = pe.JoinNode(
+        SetInterface(), joinsource=inputspec, joinfield='input1', name='join')
 
     # the joinsource is the inputspec name
     assert join.joinsource == inputspec.name, \
-                 "The joinsource is not set to the node name."
+        "The joinsource is not set to the node name."
 
 
 def test_set_join_node(tmpdir):
@@ -225,8 +228,11 @@ def test_set_join_node(tmpdir):
     pre_join1 = pe.Node(IncrementInterface(), name='pre_join1')
     wf.connect(inputspec, 'n', pre_join1, 'input1')
     # the set join node
-    join = pe.JoinNode(SetInterface(), joinsource='inputspec',
-                       joinfield='input1', name='join')
+    join = pe.JoinNode(
+        SetInterface(),
+        joinsource='inputspec',
+        joinfield='input1',
+        name='join')
     wf.connect(pre_join1, 'output1', join, 'input1')
 
     wf.run()
@@ -251,14 +257,18 @@ def test_unique_join_node(tmpdir):
     pre_join1 = pe.Node(IncrementInterface(), name='pre_join1')
     wf.connect(inputspec, 'n', pre_join1, 'input1')
     # the set join node
-    join = pe.JoinNode(SumInterface(), joinsource='inputspec',
-                       joinfield='input1', unique=True, name='join')
+    join = pe.JoinNode(
+        SumInterface(),
+        joinsource='inputspec',
+        joinfield='input1',
+        unique=True,
+        name='join')
     wf.connect(pre_join1, 'output1', join, 'input1')
 
     wf.run()
 
     assert _sum_operands[0] == [4, 2, 3], \
-                 "The unique join output value is incorrect: %s." % _sum_operands[0]
+        "The unique join output value is incorrect: %s." % _sum_operands[0]
 
 
 def test_multiple_join_nodes(tmpdir):
@@ -276,18 +286,22 @@ def test_multiple_join_nodes(tmpdir):
     pre_join1 = pe.Node(IncrementInterface(), name='pre_join1')
     wf.connect(inputspec, 'n', pre_join1, 'input1')
     # the first join node
-    join1 = pe.JoinNode(IdentityInterface(fields=['vector']),
-                        joinsource='inputspec', joinfield='vector',
-                        name='join1')
+    join1 = pe.JoinNode(
+        IdentityInterface(fields=['vector']),
+        joinsource='inputspec',
+        joinfield='vector',
+        name='join1')
     wf.connect(pre_join1, 'output1', join1, 'vector')
     # an uniterated post-join node
     post_join1 = pe.Node(SumInterface(), name='post_join1')
     wf.connect(join1, 'vector', post_join1, 'input1')
     # the downstream join node connected to both an upstream join
     # path output and a separate input in the iterated path
-    join2 = pe.JoinNode(IdentityInterface(fields=['vector', 'scalar']),
-                        joinsource='inputspec', joinfield='vector',
-                        name='join2')
+    join2 = pe.JoinNode(
+        IdentityInterface(fields=['vector', 'scalar']),
+        joinsource='inputspec',
+        joinfield='vector',
+        name='join2')
     wf.connect(pre_join1, 'output1', join2, 'vector')
     wf.connect(post_join1, 'output1', join2, 'scalar')
     # a second post-join node
@@ -323,16 +337,17 @@ def test_identity_join_node(tmpdir):
     # Make the workflow.
     wf = pe.Workflow(name='test')
     # the iterated input node
-    inputspec = pe.Node(IdentityInterface(fields=['n']),
-                        name='inputspec')
+    inputspec = pe.Node(IdentityInterface(fields=['n']), name='inputspec')
     inputspec.iterables = [('n', [1, 2, 3])]
     # a pre-join node in the iterated path
     pre_join1 = pe.Node(IncrementInterface(), name='pre_join1')
     wf.connect(inputspec, 'n', pre_join1, 'input1')
     # the IdentityInterface join node
-    join = pe.JoinNode(IdentityInterface(fields=['vector']),
-                       joinsource='inputspec', joinfield='vector',
-                       name='join')
+    join = pe.JoinNode(
+        IdentityInterface(fields=['vector']),
+        joinsource='inputspec',
+        joinfield='vector',
+        name='join')
     wf.connect(pre_join1, 'output1', join, 'vector')
     # an uniterated post-join node
     post_join1 = pe.Node(SumInterface(), name='post_join1')
@@ -358,8 +373,7 @@ def test_multifield_join_node(tmpdir):
     # Make the workflow.
     wf = pe.Workflow(name='test')
     # the iterated input node
-    inputspec = pe.Node(IdentityInterface(fields=['m', 'n']),
-                        name='inputspec')
+    inputspec = pe.Node(IdentityInterface(fields=['m', 'n']), name='inputspec')
     inputspec.iterables = [('m', [1, 2]), ('n', [3, 4])]
     # two pre-join nodes in a parallel iterated path
     inc1 = pe.Node(IncrementInterface(), name='inc1')
@@ -367,13 +381,15 @@ def test_multifield_join_node(tmpdir):
     inc2 = pe.Node(IncrementInterface(), name='inc2')
     wf.connect(inputspec, 'n', inc2, 'input1')
     # the join node
-    join = pe.JoinNode(IdentityInterface(fields=['vector1', 'vector2']),
-                       joinsource='inputspec', name='join')
+    join = pe.JoinNode(
+        IdentityInterface(fields=['vector1', 'vector2']),
+        joinsource='inputspec',
+        name='join')
     wf.connect(inc1, 'output1', join, 'vector1')
     wf.connect(inc2, 'output1', join, 'vector2')
     # a post-join node
-    prod = pe.MapNode(ProductInterface(), name='prod',
-                      iterfield=['input1', 'input2'])
+    prod = pe.MapNode(
+        ProductInterface(), name='prod', iterfield=['input1', 'input2'])
     wf.connect(join, 'vector1', prod, 'input1')
     wf.connect(join, 'vector2', prod, 'input2')
 
@@ -407,12 +423,15 @@ def test_synchronize_join_node(tmpdir):
     inc2 = pe.Node(IncrementInterface(), name='inc2')
     wf.connect(inputspec, 'n', inc2, 'input1')
     # the join node
-    join = pe.JoinNode(IdentityInterface(fields=['vector1', 'vector2']),
-                       joinsource='inputspec', name='join')
+    join = pe.JoinNode(
+        IdentityInterface(fields=['vector1', 'vector2']),
+        joinsource='inputspec',
+        name='join')
     wf.connect(inc1, 'output1', join, 'vector1')
     wf.connect(inc2, 'output1', join, 'vector2')
     # a post-join node
-    prod = pe.MapNode(ProductInterface(), name='prod', iterfield=['input1', 'input2'])
+    prod = pe.MapNode(
+        ProductInterface(), name='prod', iterfield=['input1', 'input2'])
     wf.connect(join, 'vector1', prod, 'input1')
     wf.connect(join, 'vector2', prod, 'input2')
 
@@ -422,7 +441,7 @@ def test_synchronize_join_node(tmpdir):
     # thus, the expanded graph contains 2 * 2 iteration pre-join nodes, 1 join
     # node and 1 post-join node.
     assert len(result.nodes()) == 6, \
-                 "The number of expanded nodes is incorrect."
+        "The number of expanded nodes is incorrect."
     # the product inputs are [2, 3] and [4, 5]
     assert _products == [8, 15], \
         "The post-join products is incorrect: %s." % _products
@@ -449,8 +468,11 @@ def test_itersource_join_source_node(tmpdir):
     pre_join3 = pe.Node(IncrementInterface(), name='pre_join3')
     wf.connect(pre_join2, 'output1', pre_join3, 'input1')
     # the join node
-    join = pe.JoinNode(IdentityInterface(fields=['vector']),
-                       joinsource='pre_join2', joinfield='vector', name='join')
+    join = pe.JoinNode(
+        IdentityInterface(fields=['vector']),
+        joinsource='pre_join2',
+        joinfield='vector',
+        name='join')
     wf.connect(pre_join3, 'output1', join, 'vector')
     # a join successor node
     post_join1 = pe.Node(SumInterface(), name='post_join1')
@@ -478,7 +500,7 @@ def test_itersource_join_source_node(tmpdir):
     assert [16, 19] in _sum_operands, \
         "The join Sum input is incorrect: %s." % _sum_operands
     assert [7, 9] in _sum_operands, \
-                    "The join Sum input is incorrect: %s." % _sum_operands
+        "The join Sum input is incorrect: %s." % _sum_operands
 
 
 def test_itersource_two_join_nodes(tmpdir):
@@ -503,15 +525,21 @@ def test_itersource_two_join_nodes(tmpdir):
     pre_join3 = pe.Node(IncrementInterface(), name='pre_join3')
     wf.connect(pre_join2, 'output1', pre_join3, 'input1')
     # the first join node
-    join1 = pe.JoinNode(IdentityInterface(fields=['vector']),
-                        joinsource='pre_join2', joinfield='vector', name='join1')
+    join1 = pe.JoinNode(
+        IdentityInterface(fields=['vector']),
+        joinsource='pre_join2',
+        joinfield='vector',
+        name='join1')
     wf.connect(pre_join3, 'output1', join1, 'vector')
     # a join successor node
     post_join1 = pe.Node(SumInterface(), name='post_join1')
     wf.connect(join1, 'vector', post_join1, 'input1')
     # a summary join node
-    join2 = pe.JoinNode(IdentityInterface(fields=['vector']),
-                        joinsource='inputspec', joinfield='vector', name='join2')
+    join2 = pe.JoinNode(
+        IdentityInterface(fields=['vector']),
+        joinsource='inputspec',
+        joinfield='vector',
+        name='join2')
     wf.connect(post_join1, 'output1', join2, 'vector')
 
     result = wf.run()
@@ -532,13 +560,16 @@ def test_set_join_node_file_input(tmpdir):
     wf = pe.Workflow(name='test')
     # the iterated input node
     inputspec = pe.Node(IdentityInterface(fields=['n']), name='inputspec')
-    inputspec.iterables = [('n', [tmpdir.join('test.nii').strpath, tmpdir.join('test2.nii').strpath])]
+    inputspec.iterables = [('n', [
+        tmpdir.join('test.nii').strpath,
+        tmpdir.join('test2.nii').strpath
+    ])]
     # a pre-join node in the iterated path
     pre_join1 = pe.Node(IdentityInterface(fields=['n']), name='pre_join1')
     wf.connect(inputspec, 'n', pre_join1, 'n')
     # the set join node
-    join = pe.JoinNode(PickFirst(), joinsource='inputspec',
-                       joinfield='in_files', name='join')
+    join = pe.JoinNode(
+        PickFirst(), joinsource='inputspec', joinfield='in_files', name='join')
     wf.connect(pre_join1, 'n', join, 'in_files')
 
     wf.run()
@@ -550,26 +581,27 @@ def test_nested_workflow_join(tmpdir):
 
     # Make the nested workflow
     def nested_wf(i, name='smallwf'):
-        #iterables with list of nums
+        # iterables with list of nums
         inputspec = pe.Node(IdentityInterface(fields=['n']), name='inputspec')
         inputspec.iterables = [('n', i)]
         # increment each iterable before joining
-        pre_join = pe.Node(IncrementInterface(),
-                           name='pre_join')
+        pre_join = pe.Node(IncrementInterface(), name='pre_join')
         # rejoin nums into list
-        join = pe.JoinNode(IdentityInterface(fields=['n']),
-                          joinsource='inputspec',
-                          joinfield='n',
-                          name='join')
-        #define and connect nested workflow
-        wf = pe.Workflow(name='wf_%d'%i[0])
+        join = pe.JoinNode(
+            IdentityInterface(fields=['n']),
+            joinsource='inputspec',
+            joinfield='n',
+            name='join')
+        # define and connect nested workflow
+        wf = pe.Workflow(name='wf_%d' % i[0])
         wf.connect(inputspec, 'n', pre_join, 'input1')
         wf.connect(pre_join, 'output1', join, 'n')
         return wf
+
     # master wf
     meta_wf = pe.Workflow(name='meta', base_dir='.')
     # add each mini-workflow to master
-    for i in [[1,3],[2,4]]:
+    for i in [[1, 3], [2, 4]]:
         mini_wf = nested_wf(i)
         meta_wf.add_nodes([mini_wf])
 
@@ -580,3 +612,50 @@ def test_nested_workflow_join(tmpdir):
         "The number of expanded nodes is incorrect."
 
 
+def test_name_prefix_join(tmpdir):
+    tmpdir.chdir()
+
+    def sq(x):
+        return x ** 2
+
+    wf = pe.Workflow('wf', base_dir=tmpdir.strpath)
+    square = pe.Node(Function(function=sq), name='square')
+    square.iterables = [('x', [1, 2])]
+    square_join = pe.JoinNode(Merge(1, ravel_inputs=True),
+                              name='square_join',
+                              joinsource='square',
+                              joinfield=['in1'])
+    wf.connect(square, 'out', square_join, "in1")
+    wf.run()
+
+
+def test_join_nestediters(tmpdir):
+    tmpdir.chdir()
+
+    def exponent(x, p):
+        return x ** p
+
+    wf = pe.Workflow('wf', base_dir=tmpdir.strpath)
+
+    xs = pe.Node(IdentityInterface(['x']),
+                 iterables=[('x', [1, 2])],
+                 name='xs')
+    ps = pe.Node(IdentityInterface(['p']),
+                 iterables=[('p', [3, 4])],
+                 name='ps')
+    exp = pe.Node(Function(function=exponent), name='exp')
+    exp_joinx = pe.JoinNode(Merge(1, ravel_inputs=True),
+                            name='exp_joinx',
+                            joinsource='xs',
+                            joinfield=['in1'])
+    exp_joinp = pe.JoinNode(Merge(1, ravel_inputs=True),
+                            name='exp_joinp',
+                            joinsource='ps',
+                            joinfield=['in1'])
+    wf.connect([
+        (xs, exp, [('x', 'x')]),
+        (ps, exp, [('p', 'p')]),
+        (exp, exp_joinx, [('out', 'in1')]),
+        (exp_joinx, exp_joinp, [('out', 'in1')])])
+
+    wf.run()
